ZoomableImage class

Annotations
  • @client

Constructors

ZoomableImage({required String src, String? alt, String? caption, Key? key})

Properties

alt → String?
final
caption → String?
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one component replaces another component in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
src → String
final

Methods

createElement() → Element
Creates a StatefulElement to manage this component's location in the tree.
inherited
createState() → State<StatefulComponent>
Creates the mutable state for this component at a given location in the tree.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

styles → List<StyleRule>
no setter