Node class sealed

A tree-like object that represents the content of a page.

Implementers
Available extensions

Properties

hashCode int
The hash code for this object.
no setterinherited
innerText String

Available on Node, provided by the NodeExtension extension

Recursively gets the inner text of the node.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited