Content class
A component that wraps the content of a page and applies default typographic styles.
The applies styles are based on the ContentTheme provided by the nearest Content.wrapTheme ancestor (usually the root ContentApp).
Constructors
- Content(Component child, {Key? key})
-
const
Properties
Methods
-
build(
BuildContext context) → Component - Describes the part of the user interface represented by this component.
-
createElement(
) → Element -
Creates a
StatelessElementto manage this component's location in the tree.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRebuild(
covariant Component newComponent) → bool -
Implement this method to determine whether a rebuild can be skipped.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
themeOf(
BuildContext context) → ContentTheme -
wrapTheme(
ContentTheme theme, {required Component child}) → Component